@@ -32,11 +32,14 @@
 
 ;; For `magit-rebase--todo'.
 (declare-function git-rebase-current-line "git-rebase" (&optional batch))
-(eval-and-compile
-  (cl-pushnew 'action-type eieio--known-slot-names)
+
+(eval-and-compile ;declare slot names
+  (cl-pushnew 'abbrev eieio--known-slot-names)
   (cl-pushnew 'action eieio--known-slot-names)
   (cl-pushnew 'action-options eieio--known-slot-names)
-  (cl-pushnew 'target eieio--known-slot-names))
+  (cl-pushnew 'action-type eieio--known-slot-names)
+  (cl-pushnew 'target eieio--known-slot-names)
+  (cl-pushnew 'trailer eieio--known-slot-names))
 
 ;;; Options
 ;;;; Faces
